'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var locale = require('date-fns/locale');
var dateFns = require('date-fns');
var getISOWeekYear = _interopDefault(require('date-fns/getISOWeekYear'));
var getISOWeek = _interopDefault(require('date-fns/getISOWeek'));
var getISODay = _interopDefault(require('date-fns/getISODay'));
var accounting = _interopDefault(require('accounting'));

var getDateLocale = function getDateLocale(locale$1) {
  switch (locale$1) {
    case 'nl-NL':
      return locale.nl;

    case 'en-US':
      return locale.enUS;
  }
};

var TcDate = /*#__PURE__*/function () {
  function TcDate(date, format) {
    var _this = this;

    this.getWeekDates = function (weekStartDay) {
      var startOfWeekDate = dateFns.startOfWeek(_this.date, {
        weekStartsOn: weekStartDay
      });
      var weekDates = [];

      for (var i = 0; i < 7; i++) {
        weekDates.push(dateFns.addDays(startOfWeekDate, i));
      }

      return weekDates;
    };

    this.getDayShortName = function (locale) {
      var dayShortName = _this.format('EEE d', locale);

      return dayShortName.charAt(0).toUpperCase() + dayShortName.slice(1);
    };

    this.getYearMonthDayKey = function () {
      return _this.format('yyyy-MM-dd');
    };

    this.getDateOfWeek = function (week, year) {
      var day = 1 + (week - 1) * 7;
      return new Date(year, 0, day);
    };

    this.getDateOfIsoWeek = function (week, year) {
      var simple = new Date(Date.UTC(year, 0, 1 + (week - 1) * 7));
      var dow = simple.getDay();
      var isoWeekStart = simple;

      if (dow <= 4) {
        isoWeekStart.setDate(simple.getDate() - simple.getDay() + 1);
      } else {
        isoWeekStart.setDate(simple.getDate() + 8 - simple.getDay());
      }

      return isoWeekStart;
    };

    this.getIsoWeekAndYear = function () {
      return {
        year: getISOWeekYear(_this.date),
        week: getISOWeek(_this.date),
        day: getISODay(_this.date)
      };
    };

    this.getISODay = function () {
      return getISODay(_this.date);
    };

    this.getISOYear = function () {
      return getISOWeekYear(_this.date);
    };

    this.getIsoWeek = function () {
      return getISOWeek(_this.date);
    };

    this.getDateWithoutTimeAsUTC = function () {
      if (!_this.date) {
        throw new Error('Date is null');
      }

      return new Date(Date.UTC(_this.date.getFullYear(), _this.date.getMonth(), _this.date.getDate(), 0, 0, 0, 0));
    };

    if (!date) {
      date = new Date();
    }

    if (typeof date === 'string') {
      if (format) {
        this.date = dateFns.parse(date, format, new Date());
      } else {
        this.date = dateFns.parseISO(date);
      }
    } else {
      this.date = date;
    }
  }

  var _proto = TcDate.prototype;

  _proto.toDate = function toDate() {
    return this.date;
  };

  _proto.format = function format(template, locale) {
    if (locale) {
      var localeObject = getDateLocale(locale);
      return dateFns.format(this.date, template, {
        locale: localeObject
      });
    }

    return dateFns.format(this.date, template);
  };

  _proto.add = function add(amount, type) {
    var date;

    switch (type) {
      case 'milliseconds':
      case 'millisecond':
      case 'ms':
        date = dateFns.addMilliseconds(this.date, amount);
        break;

      case 'seconds':
      case 'second':
      case 's':
        date = dateFns.addSeconds(this.date, amount);
        break;

      case 'minutes':
      case 'minute':
      case 'm':
        date = dateFns.addMinutes(this.date, amount);
        break;

      case 'hours':
      case 'hour':
      case 'h':
        date = dateFns.addHours(this.date, amount);
        break;

      case 'days':
      case 'day':
      case 'd':
        date = dateFns.addDays(this.date, amount);
        break;

      case 'weeks':
      case 'week':
      case 'w':
        date = dateFns.addWeeks(this.date, amount);
        break;

      case 'months':
      case 'month':
      case 'M':
        date = dateFns.addMonths(this.date, amount);
        break;

      case 'quarters':
      case 'quarter':
      case 'q':
        date = dateFns.addQuarters(this.date, amount);
        break;

      case 'years':
      case 'year':
      case 'y':
        date = dateFns.addYears(this.date, amount);
        break;

      default:
        throw new Error(type + " is not supported");
    }

    return new TcDate(date);
  };

  _proto.subtract = function subtract(amount, type) {
    var date;

    switch (type) {
      case 'milliseconds':
      case 'millisecond':
      case 'ms':
        date = dateFns.subMilliseconds(this.date, amount);
        break;

      case 'seconds':
      case 'second':
      case 's':
        date = dateFns.subSeconds(this.date, amount);
        break;

      case 'minutes':
      case 'minute':
      case 'm':
        date = dateFns.subMinutes(this.date, amount);
        break;

      case 'hours':
      case 'hour':
      case 'h':
        date = dateFns.subHours(this.date, amount);
        break;

      case 'days':
      case 'day':
      case 'd':
        date = dateFns.subDays(this.date, amount);
        break;

      case 'weeks':
      case 'week':
      case 'w':
        date = dateFns.subWeeks(this.date, amount);
        break;

      case 'months':
      case 'month':
      case 'M':
        date = dateFns.subMonths(this.date, amount);
        break;

      case 'quarters':
      case 'quarter':
      case 'q':
        date = dateFns.subQuarters(this.date, amount);
        break;

      case 'years':
      case 'year':
      case 'y':
        date = dateFns.subYears(this.date, amount);
        break;

      default:
        throw new Error(type + " is not supported");
    }

    return new TcDate(date);
  };

  _proto.diff = function diff(start, type) {
    var difference = dateFns.differenceInSeconds(this.date, start);

    switch (type) {
      case 'milliseconds':
      case 'millisecond':
      case 'ms':
        difference = dateFns.differenceInMilliseconds(this.date, start);
        break;

      case 'seconds':
      case 'second':
      case 's':
        difference = dateFns.differenceInSeconds(this.date, start);
        break;

      case 'minutes':
      case 'minute':
      case 'm':
        difference = dateFns.differenceInMinutes(this.date, start);
        break;

      case 'hours':
      case 'hour':
      case 'h':
        difference = dateFns.differenceInHours(this.date, start);
        break;

      case 'days':
      case 'day':
      case 'd':
        difference = dateFns.differenceInDays(this.date, start);
        break;

      case 'weeks':
      case 'week':
      case 'w':
        difference = dateFns.differenceInWeeks(this.date, start);
        break;

      case 'months':
      case 'month':
      case 'M':
        difference = dateFns.differenceInMonths(this.date, start);
        break;

      case 'quarters':
      case 'quarter':
      case 'q':
        difference = dateFns.differenceInQuarters(this.date, start);
        break;

      case 'years':
      case 'year':
      case 'y':
        difference = dateFns.differenceInYears(this.date, start);
        break;

      default:
        throw new Error(type + " is not supported");
    }

    return difference;
  };

  _proto.startOf = function startOf(type, weekStartDay) {
    var date;

    switch (type) {
      case 'seconds':
      case 'second':
      case 's':
        date = dateFns.startOfSecond(this.date);
        break;

      case 'minutes':
      case 'minute':
      case 'm':
        date = dateFns.startOfMinute(this.date);
        break;

      case 'hours':
      case 'hour':
      case 'h':
        date = dateFns.startOfHour(this.date);
        break;

      case 'days':
      case 'day':
      case 'd':
        date = dateFns.startOfDay(this.date);
        break;

      case 'weeks':
      case 'week':
      case 'w':
        date = dateFns.startOfWeek(this.date, {
          weekStartsOn: weekStartDay
        });
        break;

      case 'months':
      case 'month':
      case 'M':
        date = dateFns.startOfMonth(this.date);
        break;

      case 'quarters':
      case 'quarter':
      case 'q':
        date = dateFns.startOfQuarter(this.date);
        break;

      case 'years':
      case 'year':
      case 'y':
        date = dateFns.startOfYear(this.date);
        break;

      default:
        throw new Error(type + " is not supported");
    }

    return new TcDate(date);
  };

  _proto.endOf = function endOf(type, weekStartDay) {
    var date;

    switch (type) {
      case 'seconds':
      case 'second':
      case 's':
        date = dateFns.endOfSecond(this.date);
        break;

      case 'minutes':
      case 'minute':
      case 'm':
        date = dateFns.endOfMinute(this.date);
        break;

      case 'hours':
      case 'hour':
      case 'h':
        date = dateFns.endOfHour(this.date);
        break;

      case 'days':
      case 'day':
      case 'd':
        date = dateFns.endOfDay(this.date);
        break;

      case 'weeks':
      case 'week':
      case 'w':
        date = dateFns.endOfWeek(this.date, {
          weekStartsOn: weekStartDay
        });
        break;

      case 'months':
      case 'month':
      case 'M':
        date = dateFns.endOfMonth(this.date);
        break;

      case 'quarters':
      case 'quarter':
      case 'q':
        date = dateFns.endOfQuarter(this.date);
        break;

      case 'years':
      case 'year':
      case 'y':
        date = dateFns.endOfYear(this.date);
        break;

      default:
        throw new Error(type + " is not supported");
    }

    return new TcDate(date);
  };

  _proto.weekday = function weekday() {
    return dateFns.getDay(this.date);
  };

  _proto.weekdayToDate = function weekdayToDate(day, weekStartDay) {
    return dateFns.setDay(this.date, day, {
      weekStartsOn: weekStartDay
    });
  };

  _proto.week = function week(weekStartDay) {
    return dateFns.getWeek(this.date, {
      weekStartsOn: weekStartDay
    });
  };

  _proto.year = function year() {
    return dateFns.getYear(this.date);
  };

  _proto.isSame = function isSame(dateToCheck, type, weekStartDay) {
    switch (type) {
      case 'days':
      case 'day':
      case 'd':
        return dateFns.isSameDay(this.date, dateToCheck);

      case 'weeks':
      case 'week':
      case 'w':
        return dateFns.isSameWeek(this.date, dateToCheck, {
          weekStartsOn: weekStartDay
        });

      case 'months':
      case 'month':
      case 'M':
        return dateFns.isSameMonth(this.date, dateToCheck);

      case 'quarters':
      case 'quarter':
      case 'q':
        return dateFns.isSameQuarter(this.date, dateToCheck);

      case 'years':
      case 'year':
      case 'y':
        return dateFns.isSameYear(this.date, dateToCheck);

      default:
        throw new Error(type + " is not supported");
    }
  };

  _proto.isBetween = function isBetween(_ref) {
    var start = _ref.start,
        end = _ref.end;
    return dateFns.isWithinInterval(this.date, {
      start: start,
      end: end
    });
  };

  _proto.isAfter = function isAfter(dateToCheck) {
    return dateFns.isAfter(this.date, dateToCheck);
  };

  _proto.isValid = function isValid() {
    return dateFns.isValid(this.date);
  };

  _proto.set = function set(amount, type) {
    var date;

    switch (type) {
      case 'second':
      case 'seconds':
        date = dateFns.setSeconds(this.date, amount);
        break;

      case 'minute':
      case 'minutes':
        date = dateFns.setMinutes(this.date, amount);
        break;

      case 'hour':
      case 'hours':
        date = dateFns.setHours(this.date, amount);
    }

    return new TcDate(date);
  };

  _proto.daysInMonth = function daysInMonth() {
    return dateFns.getDaysInMonth(this.date);
  };

  _proto.toISOString = function toISOString() {
    return this.date.toISOString();
  };

  _proto.interval = function interval(start, end) {
    return dateFns.eachDayOfInterval({
      start: start,
      end: end
    });
  };

  return TcDate;
}();

function _extends() {
  _extends = Object.assign || function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];

      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }

    return target;
  };

  return _extends.apply(this, arguments);
}

function getCurrencies() {
  return [{
    id: 'AED',
    name: 'UAE Dirham',
    fractionSize: 2,
    symbol: {
      grapheme: '.د.إ',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: null
  }, {
    id: 'AFN',
    name: 'Afghani',
    fractionSize: 2,
    symbol: {
      grapheme: '؋',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '؋',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'ALL',
    name: 'Lek',
    fractionSize: 2,
    symbol: {
      grapheme: 'L',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Lek',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'AMD',
    name: 'Armenian Dram',
    fractionSize: 2,
    symbol: {
      grapheme: 'դր.',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'դր.',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'ANG',
    name: 'Netherlands Antillean Guilder',
    fractionSize: 2,
    symbol: {
      grapheme: 'ƒ',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'NAƒ',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'AOA',
    name: 'Kwanza',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'ARS',
    name: 'Argentine Peso',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'AUD',
    name: 'Australian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'A$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'AWG',
    name: 'Aruban Florin',
    fractionSize: 2,
    symbol: {
      grapheme: 'ƒ',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Afl',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'AZN',
    name: 'Azerbaijanian Manat',
    fractionSize: 2,
    symbol: {
      grapheme: '₼',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₼',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BAM',
    name: 'Convertible Mark',
    fractionSize: 2,
    symbol: {
      grapheme: 'KM',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'KM',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BBD',
    name: 'Barbados Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'BDT',
    name: 'Taka',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BGN',
    name: 'Bulgarian Lev',
    fractionSize: 2,
    symbol: {
      grapheme: 'лв',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'лв',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BHD',
    name: 'Bahraini Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ب',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ب',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'BIF',
    name: 'Burundi Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BMD',
    name: 'Bermudian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'BD$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BND',
    name: 'Brunei Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'BOB',
    name: 'Boliviano',
    fractionSize: 2,
    symbol: {
      grapheme: 'Bs.',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Bs.',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BOV',
    name: 'Mvdol',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BRL',
    name: 'Brazilian Real',
    fractionSize: 2,
    symbol: {
      grapheme: 'R$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'R$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BSD',
    name: 'Bahamian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'BTN',
    name: 'Ngultrum',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BWP',
    name: 'Pula',
    fractionSize: 2,
    symbol: {
      grapheme: 'P',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'P',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'BYN',
    name: 'Belarussian Ruble',
    fractionSize: 2,
    symbol: {
      grapheme: 'p.',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'р.',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'BYR',
    name: 'Belarussian Ruble',
    fractionSize: 0,
    symbol: {
      grapheme: 'p.',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'р.',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'BZD',
    name: 'Belize Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: 'BZ$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'BZ$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'CAD',
    name: 'Canadian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'CA$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'CDF',
    name: 'Congolese Franc',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CHE',
    name: 'WIR Euro',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CHF',
    name: 'Swiss Franc',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CHW',
    name: 'WIR Franc',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CLF',
    name: 'Unidad de Fomento',
    fractionSize: 4,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CLP',
    name: 'Chilean Peso',
    fractionSize: 0,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'CNY',
    name: 'Yuan Renminbi',
    fractionSize: 2,
    symbol: {
      grapheme: '元',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '元',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'COP',
    name: 'Colombian Peso',
    fractionSize: 0,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'COU',
    name: 'Unidad de Valor Real',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CRC',
    name: 'Cost Rican Colon',
    fractionSize: 2,
    symbol: {
      grapheme: '₡',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₡',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'CUC',
    name: 'Peso Convertible',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CUP',
    name: 'Cuban Peso',
    fractionSize: 2,
    symbol: {
      grapheme: '$MN',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '$MN',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'CVE',
    name: 'Cabo Verde Escudo',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'CZK',
    name: 'Czech Koruna',
    fractionSize: 2,
    symbol: {
      grapheme: 'Kč',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Kč',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'DJF',
    name: 'Djibouti Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'DKK',
    name: 'Danish Krone',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'DOP',
    name: 'Dominican Peso',
    fractionSize: 2,
    symbol: {
      grapheme: 'RD$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'RD$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'DZD',
    name: 'Algerian Dinar',
    fractionSize: 2,
    symbol: {
      grapheme: '.د.ج',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ج',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'EEK',
    name: 'Estonian Kroon',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'EGP',
    name: 'Egyptian Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '.ج.م',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'ERN',
    name: 'Nakfa',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'ETB',
    name: 'Ethiopian Birr',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'EUR',
    name: 'Euro',
    fractionSize: 2,
    symbol: {
      grapheme: '€',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '€',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'FJD',
    name: 'Fiji Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'FJ$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'FKP',
    name: 'Falkland Islands Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'GBP',
    name: 'Pound Sterling',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'GEL',
    name: 'Lari',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'GGP',
    name: 'Guernsey Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'GHC',
    name: 'Ghanaian Cedi',
    fractionSize: 2,
    symbol: {
      grapheme: '¢',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '¢',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'GHS',
    name: 'Ghan Cedi',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'GIP',
    name: 'Gibraltar Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'GMD',
    name: 'Dalasi',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'GNF',
    name: 'Guine Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'GTQ',
    name: 'Quetzal',
    fractionSize: 2,
    symbol: {
      grapheme: 'Q',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Q',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'GYD',
    name: 'Guyan Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'GY$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'HKD',
    name: 'Hong Kong Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'HK$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'HNL',
    name: 'Lempira',
    fractionSize: 2,
    symbol: {
      grapheme: 'L',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'L',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'HRK',
    name: 'Croatian Kuna',
    fractionSize: 2,
    symbol: {
      grapheme: 'kn',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'kn',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'HTG',
    name: 'Gourde',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'HUF',
    name: 'Forint',
    fractionSize: 0,
    symbol: {
      grapheme: 'Ft',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Ft',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'IDR',
    name: 'Rupiah',
    fractionSize: 2,
    symbol: {
      grapheme: 'Rp',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Rp',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'ILS',
    name: 'New Israeli Sheqel',
    fractionSize: 2,
    symbol: {
      grapheme: '₪',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₪',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'IMP',
    name: 'Manx Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'INR',
    name: 'Indian Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₹',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₹',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'IQD',
    name: 'Iraqi Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ع',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ع',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'IRR',
    name: 'Iranian Rial',
    fractionSize: 0,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'ISK',
    name: 'Iceland Krona',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'JEP',
    name: 'Jersey Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'JMD',
    name: 'Jamaican Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: 'J$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'J$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'JOD',
    name: 'Jordanian Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.إ',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: null
  }, {
    id: 'JPY',
    name: 'Yen',
    fractionSize: 0,
    symbol: {
      grapheme: '¥',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '¥',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KES',
    name: 'Kenyan Shilling',
    fractionSize: 2,
    symbol: {
      grapheme: 'KSh',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'KSh',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KGS',
    name: 'Som',
    fractionSize: 2,
    symbol: {
      grapheme: 'сом',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'сом',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KHR',
    name: 'Riel',
    fractionSize: 2,
    symbol: {
      grapheme: '៛',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '៛',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KMF',
    name: 'Comoro Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'KPW',
    name: 'North Korean Won',
    fractionSize: 0,
    symbol: {
      grapheme: '₩',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'KRW',
    name: 'Won',
    fractionSize: 0,
    symbol: {
      grapheme: '₩',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₩',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KWD',
    name: 'Kuwaiti Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ك',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ك',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'KYD',
    name: 'Cayman Islands Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'CI$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'KZT',
    name: 'Tenge',
    fractionSize: 2,
    symbol: {
      grapheme: '₸',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₸',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'LAK',
    name: 'Kip',
    fractionSize: 2,
    symbol: {
      grapheme: '₭',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₭',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'LBP',
    name: 'Lebanese Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '.ل.ل',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'LKR',
    name: 'Sri Lank Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'LRD',
    name: 'Liberian Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'L$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'LSL',
    name: 'Loti',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'LTL',
    name: 'Lithuanian Litas',
    fractionSize: 2,
    symbol: {
      grapheme: 'Lt',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Lt',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'LVL',
    name: 'Latvian Lats',
    fractionSize: 2,
    symbol: {
      grapheme: 'Ls',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Ls',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'LYD',
    name: 'Libyan Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ل',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ل',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'MAD',
    name: 'Moroccan Dirham',
    fractionSize: 2,
    symbol: {
      grapheme: '.د.م',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.م',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'MDL',
    name: 'Moldovan Leu',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MGA',
    name: 'Malagasy ariary',
    fractionSize: 1,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MKD',
    name: 'Denar',
    fractionSize: 2,
    symbol: {
      grapheme: 'ден',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'ден',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'MMK',
    name: 'Kyat',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MNT',
    name: 'Tugrik',
    fractionSize: 2,
    symbol: {
      grapheme: '₮',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₮',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'MOP',
    name: 'Pataca',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MRO',
    name: 'Ouguiya',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MUR',
    name: 'Mauritius Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'MVR',
    name: 'Rufiyaa',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MWK',
    name: 'Kwacha',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MXN',
    name: 'Mexican Peso',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'MXV',
    name: 'Mexican Unidad de Inversion (UDI)',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'MYR',
    name: 'Malaysian Ringgit',
    fractionSize: 2,
    symbol: {
      grapheme: 'RM',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'RM',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'MZN',
    name: 'Mozambique Metical',
    fractionSize: 2,
    symbol: {
      grapheme: 'MT',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'MT',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'NAD',
    name: 'Namibi Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'N$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'NGN',
    name: 'Naira',
    fractionSize: 2,
    symbol: {
      grapheme: '₦',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₦',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'NIO',
    name: 'Cordob Oro',
    fractionSize: 2,
    symbol: {
      grapheme: 'C$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'C$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'NOK',
    name: 'Norwegian Krone',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'NPR',
    name: 'Nepalese Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'NZD',
    name: 'New Zealand Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'NZ$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'OMR',
    name: 'Rial Omani',
    fractionSize: 3,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.ر.ع',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'PAB',
    name: 'Balboa',
    fractionSize: 2,
    symbol: {
      grapheme: 'B/.',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'B/.',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'PEN',
    name: 'Nuevo Sol',
    fractionSize: 2,
    symbol: {
      grapheme: 'S/',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'S/',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'PGK',
    name: 'Kina',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'PHP',
    name: 'Philippine Peso',
    fractionSize: 2,
    symbol: {
      grapheme: '₱',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₱',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'PKR',
    name: 'Pakistan Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'PLN',
    name: 'Zloty',
    fractionSize: 2,
    symbol: {
      grapheme: 'zł',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'zł',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'PYG',
    name: 'Guarani',
    fractionSize: 0,
    symbol: {
      grapheme: 'Gs',
      template: '1$',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Gs',
      template: '1$',
      rtl: false
    }
  }, {
    id: 'QAR',
    name: 'Qatari Rial',
    fractionSize: 2,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.ر.ق',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'RON',
    name: 'New Romanian Leu',
    fractionSize: 2,
    symbol: {
      grapheme: 'lei',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'lei',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'RSD',
    name: 'Serbian Dinar',
    fractionSize: 2,
    symbol: {
      grapheme: 'Дин.',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Дин.',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'RUB',
    name: 'Russian Ruble',
    fractionSize: 2,
    symbol: {
      grapheme: '₽',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₽',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'RUR',
    name: 'Russian Ruble',
    fractionSize: 2,
    symbol: {
      grapheme: '₽',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₽',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'RWF',
    name: 'Rwand Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'SAR',
    name: 'Saudi Riyal',
    fractionSize: 2,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.ر.س',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'SBD',
    name: 'Solomon Islands Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'SI$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'SCR',
    name: 'Seychelles Rupee',
    fractionSize: 2,
    symbol: {
      grapheme: '₨',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'SDG',
    name: 'Sudanese Pound',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'SEK',
    name: 'Swedish Krona',
    fractionSize: 2,
    symbol: {
      grapheme: 'kr',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'SGD',
    name: 'Singapore Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'S$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'SHP',
    name: 'Saint Helen Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'SLL',
    name: 'Leone',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'SOS',
    name: 'Somali Shilling',
    fractionSize: 2,
    symbol: {
      grapheme: 'S',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'S',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'SRD',
    name: 'Surinam Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'SSP',
    name: 'South Sudanese Pound',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'STD',
    name: 'Dobra',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'SVC',
    name: 'El Salvador Colon',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'C',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'SYP',
    name: 'Syrian Pound',
    fractionSize: 2,
    symbol: {
      grapheme: '£',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '.ل.س',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'SZL',
    name: 'Lilangeni',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'THB',
    name: 'Baht',
    fractionSize: 2,
    symbol: {
      grapheme: '฿',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '฿',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'TJS',
    name: 'Somoni',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'TMT',
    name: 'Turkmenistan New Manat',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'TND',
    name: 'Tunisian Dinar',
    fractionSize: 3,
    symbol: {
      grapheme: '.د.ت',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.د.ت',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'TOP',
    name: 'Pa’anga',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'TRL',
    name: 'Turkish Lira',
    fractionSize: 2,
    symbol: {
      grapheme: '₤',
      template: '$1',
      rtl: false
    },
    uniqSymbol: null
  }, {
    id: 'TRY',
    name: 'Turkish Lira',
    fractionSize: 2,
    symbol: {
      grapheme: '₺',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₺',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'TTD',
    name: 'Trinidad and Tobago Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: 'TT$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'TT$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'TWD',
    name: 'New Taiwan Dollar',
    fractionSize: 0,
    symbol: {
      grapheme: 'NT$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'NT$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'TZS',
    name: 'Tanzanian Shilling',
    fractionSize: 0,
    symbol: {
      grapheme: 'TSh',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'TSh',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'UAH',
    name: 'Hryvnia',
    fractionSize: 2,
    symbol: {
      grapheme: '₴',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₴',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'UGX',
    name: 'Ugand Shilling',
    fractionSize: 0,
    symbol: {
      grapheme: 'USh',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'USh',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'USD',
    name: 'US Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'USN',
    name: 'US Dollar (Next day)',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'UYI',
    name: 'Uruguay Peso en Unidades Indexadas (URUIURUI)',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'UYU',
    name: 'Peso Uruguayo',
    fractionSize: 0,
    symbol: {
      grapheme: '$U',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '$U',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'UZS',
    name: 'Uzbekistan Sum',
    fractionSize: 2,
    symbol: {
      grapheme: 'so’m',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'so’m',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'VEF',
    name: 'Bolivar',
    fractionSize: 2,
    symbol: {
      grapheme: 'Bs',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Bs',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'VES',
    name: 'Bolivar',
    fractionSize: 2,
    symbol: {
      grapheme: 'Bs',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Bs',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'VND',
    name: 'Dong',
    fractionSize: 0,
    symbol: {
      grapheme: '₫',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₫',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'VUV',
    name: 'Vatu',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'WST',
    name: 'Tala',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'XAF',
    name: 'CFA Franc BEAC',
    fractionSize: 0,
    symbol: {
      grapheme: 'FCFA',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'FCFA',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'XCD',
    name: 'East Caribbean Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: '$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'EC$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'XDR',
    name: 'SDR (Special Drawing Right)',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'XOF',
    name: 'CFA Franc BCEAO',
    fractionSize: 0,
    symbol: {
      grapheme: 'CFA',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'CFA',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'XPF',
    name: 'CFP Franc',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'XSU',
    name: 'Sucre',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'XUA',
    name: 'ADB Unit of Account',
    fractionSize: 0,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'YER',
    name: 'Yemeni Rial',
    fractionSize: 2,
    symbol: {
      grapheme: '﷼',
      template: '1 $',
      rtl: true
    },
    uniqSymbol: {
      grapheme: '.ر.ي',
      template: '1 $',
      rtl: true
    }
  }, {
    id: 'ZAR',
    name: 'Rand',
    fractionSize: 2,
    symbol: {
      grapheme: 'R',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'R',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'ZMW',
    name: 'Zambian Kwacha',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'ZWD',
    name: 'Zimbabwe Dollar',
    fractionSize: 2,
    symbol: {
      grapheme: 'Z$',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Z$',
      template: '$1',
      rtl: false
    }
  }, {
    id: 'ZWL',
    name: 'Zimbabwe Dollar',
    fractionSize: 2,
    symbol: null,
    uniqSymbol: null
  }, {
    id: 'BTC',
    name: 'BTC',
    fractionSize: 4,
    symbol: {
      grapheme: '₿',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '₿',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'ETH',
    name: 'ETH',
    fractionSize: 4,
    symbol: {
      grapheme: 'Ξ',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Ξ',
      template: '1 $',
      rtl: false
    }
  }, {
    id: 'LTC',
    name: 'LTC',
    fractionSize: 4,
    symbol: {
      grapheme: 'Ł',
      template: '1 $',
      rtl: false
    },
    uniqSymbol: {
      grapheme: 'Ł',
      template: '1 $',
      rtl: false
    }
  }];
}

function formatCurrency(input, currency, numberFormat) {
  if (currency === void 0) {
    currency = 'EUR';
  }

  if (numberFormat === void 0) {
    numberFormat = 'comma';
  }

  var currencies = getCurrencies();
  var currencyObject = currencies.find(function (x) {
    return x.id === currency;
  }) || {
    id: 'EUR',
    name: 'Euro',
    fractionSize: 2,
    symbol: {
      grapheme: '€',
      template: '$1',
      rtl: false
    },
    uniqSymbol: {
      grapheme: '€',
      template: '$1',
      rtl: false
    }
  };
  var symbol = currencyObject.symbol,
      fractionSize = currencyObject.fractionSize;
  var result;

  if (symbol) {
    var grapheme = symbol.grapheme,
        template = symbol.template;
    var format = template.replace('$', '%s').replace('1', '%v');
    result = {
      symbol: grapheme,
      format: format,
      fractionSize: fractionSize
    };
  } else {
    result = {
      symbol: currencyObject.id,
      fractionSize: fractionSize
    };
  }

  switch (numberFormat) {
    case 'dot':
      return accounting.formatMoney(input, _extends({}, result, {
        decimal: '.',
        thousand: ','
      }));

    case 'space':
      return accounting.formatMoney(input, _extends({}, result, {
        decimal: ',',
        thousand: ' '
      }));

    case 'comma':
    default:
      return accounting.formatMoney(input, _extends({}, result, {
        decimal: ',',
        thousand: '.'
      }));
  }
}

function unformatCurrency(input, numberFormat) {
  if (numberFormat === void 0) {
    numberFormat = 'comma';
  }

  switch (numberFormat) {
    case 'dot':
      return accounting.unformat(input, '.');

    case 'space':
      return accounting.unformat(input, ',');

    case 'comma':
    default:
      return accounting.unformat(input, ',');
  }
}

function formatFloat(input, max24) {
  if (!input) {
    return 0;
  }

  var _float = 0.0;
  var isNegative = false; // replace comma for dot

  input = input.replace(',', '.'); // is negative value

  if (input.includes('-')) {
    input = input.replace('-', '');
    isNegative = true;
  }

  if (input.includes(':')) {
    // 01:30    = 1.5 hour
    // 1:30     = 1.5 hour
    // :30      = 0.5 hour
    var h = parseInt(input.split(':')[0], 10) || 0;
    var m = parseFloat(input.split(':')[1]) / 60;
    _float = h + m;
  } else if (!input.includes('.') && (input.length === 3 || input.length === 4)) {
    // 0130     = 1.5 hour
    // 130      = 1.5 hour
    input = input.replace(/^0/, '');

    if (input.length === 3) {
      var _h = parseInt(input[0], 10);

      var _m = parseFloat(input[1] + input[2]) / 60;

      _float = _h + _m;
    } else {
      var _h2 = parseInt(input[0] + input[1], 10);

      var _m2 = parseFloat(input[2] + input[3]) / 60;

      _float = _h2 + _m2;
    }
  } else {
    // 1.5      = 1.5 hour
    // 1,5      = 1.5 hour
    // .5       = 0.5 hour
    // ,5       = 0.5 hour
    // 24       = 24 hour
    // 1        = 1 hour
    _float = parseFloat(input);
  }

  if (isNaN(_float)) {
    _float = 0;
  }

  if (max24 && _float > 24) {
    _float = 24;
  }

  if (isNegative) {
    _float = _float * -1;
  }

  return _float;
}

function formatNumber(input, precision, numberFormat) {
  if (precision === void 0) {
    precision = 2;
  }

  if (numberFormat === void 0) {
    numberFormat = 'comma';
  }

  switch (numberFormat) {
    case 'dot':
      return accounting.formatNumber(input, precision, ',', '.');

    case 'space':
      return accounting.formatNumber(input, precision, ',', ' ');

    case 'apostrophe':
      return accounting.formatNumber(input, precision, '.', "'");

    case 'comma':
    default:
      return accounting.formatNumber(input, precision, '.', ',');
  }
}

function formatDistance(input, distance, symbol, precision, numberFormat) {
  if (symbol === void 0) {
    symbol = true;
  }

  if (precision === void 0) {
    precision = 2;
  }

  if (numberFormat === void 0) {
    numberFormat = 'comma';
  }

  var converted;

  if (distance === 'mi') {
    converted = input * 0.000621371192;
  } else {
    converted = input / 1000;
  }

  var formatted = formatNumber(converted, precision, numberFormat);

  if (!symbol) {
    return formatted;
  }

  return distance === 'km' ? formatted + " KM" : formatted + " mi";
}

function formatTime(seconds, format) {
  if (format === void 0) {
    format = 'HH:mm:ss';
  }

  if (isNaN(seconds)) {
    seconds = 0;
  }

  var time = '';
  var isNegative = false;

  if (seconds < 0) {
    isNegative = true;
    seconds = Math.abs(seconds);
  }

  if (format === 'HH:mm:ss') {
    var hour = Math.floor(seconds / 3600);
    var minute = Math.floor((seconds - hour * 3600) / 60);
    var second = Math.floor(seconds - hour * 3600 - minute * 60);
    var formatedHour = hour < 10 ? "0" + hour : hour;

    if (minute < 10) {
      time = formatedHour + ":0" + minute;
    } else {
      time = formatedHour + ":" + minute;
    }

    if (second < 10) {
      time = time + ":0" + second;
    } else {
      time = time + ":" + second;
    }
  } else if (format === 'HH:mm') {
    var _hour = Math.floor(seconds / 3600);

    var _minute = Math.round((seconds - _hour * 3600) / 60);

    var _formatedHour = _hour < 10 ? "0" + _hour : _hour;

    if (_minute < 10) {
      time = _formatedHour + ":0" + _minute;
    } else {
      time = _formatedHour + ":" + _minute;
    }
  } else if (format === 'decimal') {
    time = formatNumber(seconds / 3600);
  }

  if (isNegative) {
    time = "-" + time;
  }

  return time;
}

function formatUppercase(input) {
  return "" + input.charAt(0).toUpperCase() + input.slice(1);
}

function cloneObject(obj) {
  if (!obj) {
    return null;
  }

  return JSON.parse(JSON.stringify(obj));
}

function dynamicSort(property) {
  var sortOrder = 1;

  if (property[0] === '-') {
    sortOrder = -1;
    property = property.substr(1);
  }

  return function (a, b) {
    if (a[property] < b[property]) {
      return -1 * sortOrder;
    }

    if (a[property] > b[property]) {
      return 1 * sortOrder;
    }

    return 0;
  };
}

function globalVarExists(nameOfVariable) {
  return nameOfVariable in window;
}

function dynamicSortMultiple(props) {
  return function (obj1, obj2) {
    var i = 0;
    var result = 0;

    while (result === 0 && i < props.length) {
      result = dynamicSort(props[i])(obj1, obj2);
      i++;
    }

    return result;
  };
}

function guid() {
  function s4() {
    return Math.floor((1 + Math.random()) * 0x10000).toString(16).substring(1);
  }

  return s4() + s4() + '-' + s4() + '-' + s4() + '-' + s4() + '-' + s4() + s4() + s4();
}

function sortBy(list, props) {
  var orderList = new Array().concat(list);
  return orderList.sort(dynamicSortMultiple(props));
}

function filterBy(list, props, query) {
  if (!query) {
    return list;
  }

  return [].concat(list).filter(function (item) {
    var match = false;
    props.forEach(function (prop) {
      if (item[prop] && item[prop].toLowerCase().includes(query.toLowerCase())) {
        match = true;
      }
    });
    return match;
  });
}

function toggleArray(array, objs) {
  if (!array) {
    return [];
  }

  var arrayClone = [].concat(array);
  objs.forEach(function (obj) {
    if (arrayClone.includes(obj)) {
      arrayClone = arrayClone.filter(function (x) {
        return x !== obj;
      });
    } else {
      arrayClone.push(obj);
    }
  });
  return arrayClone;
}

function tryParseInt(str, defaultValue) {
  var retValue = defaultValue;

  if (str !== null && str !== undefined) {
    if (str.length > 0) {
      if (!isNaN(str)) {
        retValue = parseInt(str, 10);
      }
    }
  }

  return retValue;
}

function tryParseFloat(str, defaultValue) {
  var retValue = defaultValue;

  if (str !== null && str !== undefined) {
    if (str.length >= 0) {
      if (!isNaN(str)) {
        retValue = parseFloat(str);
      }
    }
  }

  return retValue;
}

function maxChar(str, maxChar) {
  if (str && maxChar && str.length > maxChar) {
    str = str.substring(0, maxChar);
  }

  return str;
}

function slugify(str, separator, max) {
  if (!str) {
    return '';
  }

  str = str.trim();
  str = str.toLowerCase();
  var from = 'åàáãäâèéëêìíïîòóöôùúüûñç·/_,:;';
  var to = 'aaaaaaeeeeiiiioooouuuunc------';

  for (var i = 0, l = from.length; i < l; i++) {
    str = str.replace(new RegExp(from.charAt(i), 'g'), to.charAt(i));
  }

  str = str.replace(/[^a-z0-9 -]/g, '').replace(/\s+/g, '-').replace(/-+/g, '-').replace(/^-+/, '').replace(/-+$/, '').replace(/-/g, separator);
  return maxChar(str, max);
}

function compareArray(array1, array2) {
  var array1Clone = [].concat(array1).sort();
  var array2Clone = [].concat(array2).sort();
  return array1Clone.length === array2Clone.length && array1Clone.every(function (value, index) {
    return value === array2Clone[index];
  });
}

function hasSubArray(master, sub) {
  return sub.every(function (val) {
    return master.includes(val);
  });
}

function roundNumber(input, roundingType, roundingValue) {
  switch (roundingType) {
    case 'up':
      return Math.ceil(input / roundingValue) * roundingValue;

    case 'down':
      var str = (input / 60).toString();
      return parseInt(str, 10) * 60;

    case 'nearest':
      return Math.round(input / 60) * 60;

    default:
      throw new Error('roundingType not found');
  }
}

function enumToSelectList(myEnum) {
  var list = Object.keys(myEnum).filter(function (k) {
    return typeof myEnum[k] !== 'number';
  }).map(function (key) {
    return {
      id: parseInt(key, 10),
      name: "" + myEnum[key]
    };
  });
  return list.filter(function (x) {
    return x.id !== 0;
  });
}

function isMobile() {
  return document.documentElement.clientWidth <= 767;
}

function sortCaseInsensitive(arr, prop) {
  return arr.sort(function (a, b) {
    if (a[prop] && b[prop]) {
      var nameA = a[prop].toUpperCase();
      var nameB = b[prop].toUpperCase();

      if (nameA < nameB) {
        return -1;
      }

      if (nameA > nameB) {
        return 1;
      }
    }

    return 0;
  });
}

var delay = function delay(milliseconds) {
  return new Promise(function (resolve) {
    setTimeout(resolve, milliseconds);
  });
};

var getNumeric = function getNumeric(value) {
  return +value.replace(/[^0-9]/g, '');
};

var imageFileToBase64 = function imageFileToBase64(file) {
  var reader = new FileReader();
  return new Promise(function (resolve) {
    reader.onloadend = function () {
      resolve("" + reader.result);
    };

    reader.readAsDataURL(file);
  });
};

/**
 * Typically, when calculating module of negative number, it should become positive.
 * JavaScript's '%' operator does not support this behavior. This helper converts
 * negative number to positive, if needed.
 */
var mod = function mod(value, n) {
  return (value % n + n) % n;
};

/**
 * Converts dash-separated locales to single-worded locale.
 * @param longLocaleCode - examples: en-US, nl-NL
 */
var getShortLocaleCode = function getShortLocaleCode(longLocaleCode) {
  return (longLocaleCode || '').split('-')[0];
};

// Validates if the name is in the object of type T
var nameOf = function nameOf(name) {
  return name;
};

var minimumDelay = function minimumDelay(func, startTime, mininumMs) {
  var diff = new TcDate().diff(startTime, 'millisecond');
  var ms = diff < mininumMs ? mininumMs - diff : 0;
  setTimeout(func, ms);
};

function getInputValueByName(name) {
  var field = document.getElementsByName(name);

  if (field && field.length > 0) {
    return field[0].value;
  }

  return null;
}
function setInputValueByName(name, value) {
  var field = document.getElementsByName(name);

  if (field && field.length > 0) {
    var input = field[0];
    input.value = value;
  }
}
function setInputCheckedByName(name, checked) {
  var field = document.getElementsByName(name);

  if (field && field.length > 0) {
    var input = field[0];
    input.checked = checked;
  }
}

var secondsToHours = function secondsToHours(seconds) {
  if (seconds === void 0) {
    seconds = 0;
  }

  return seconds / 3600;
};
var hoursToSeconds = function hoursToSeconds(hours) {
  if (hours === void 0) {
    hours = 0;
  }

  return hours * 3600;
};
var formatToSeconds = function formatToSeconds(input, max24) {
  if (max24 === void 0) {
    max24 = true;
  }

  var result = {
    isValid: false,
    seconds: null
  };

  if (!input) {
    result.isValid = true;
    return result;
  }

  var isNegative = false; // replace comma/semicolon for dot

  input = input.replace(',', '.').replace(';', '.'); // is negative value

  if (input.includes('-')) {
    input = input.replace('-', '');
    isNegative = true;
  } // 01:30    = 1.5 hour
  // 1:30     = 1.5 hour
  // :30      = 0.5 hour


  if (input.includes(':')) {
    var h = parseInt(input.split(':')[0], 10) || 0;
    var m = parseFloat(input.split(':')[1]) / 60;
    result.seconds = (h + m) * 3600;
  } // 1h30m       = 1.5 hour
  else if (input.includes('h') && input.includes('m')) {
      var a = input.split(/h|m/);

      var _h = parseInt(a[0], 10) || 0;

      var _m = parseFloat(a[1]) / 60;

      result.seconds = (_h + _m) * 3600;
    } // 1h       = 1 hour
    else if (input.includes('h')) {
        input = input.replace('h', '');
        result.seconds = parseFloat(input) * 3600;
      } // 1m       = 1 minute
      else if (input.includes('m')) {
          input = input.replace('m', '');
          result.seconds = parseFloat(input) * 60;
        } // 1.5      = 1.5 hour
        // .5       = 0.5 hour
        else if (input.includes('.')) {
            result.seconds = parseFloat(input) * 3600;
          } // 0130     = 1.5 hour
          // 130      = 1.5 hour
          else if (input.length === 3) {
              result.seconds = parseFloat(input) * 60;
            } // 0130     = 1.5 hour
            // 1130     = 11.5 hour
            else if (input.length === 4) {
                input = input.replace(/^0/, '');

                if (input.length === 3) {
                  var _h2 = parseInt(input[0], 10);

                  var _m2 = parseFloat(input[1] + input[2]) / 60;

                  result.seconds = (_h2 + _m2) * 3600;
                } else {
                  var _h3 = parseInt(input[0] + input[1], 10);

                  var _m3 = parseFloat(input[2] + input[3]) / 60;

                  result.seconds = (_h3 + _m3) * 3600;
                }
              } // 24       = 24 hour
              // 1        = 1 hour
              else {
                  result.seconds = parseFloat(input) * 3600;
                }

  if (max24 && result.seconds > 24 * 3600) {
    result.seconds = 24 * 3600;
  }

  if (isNegative) {
    result.seconds = result.seconds * -1;
  }

  if (!isNaN(result.seconds)) {
    result.isValid = true;
  }

  return result;
};
var formatToTime = function formatToTime(seconds, format) {
  if (format === void 0) {
    format = 'HH:mm';
  }

  if (isNaN(seconds)) {
    seconds = 0;
  }

  var time = '';
  var isNegative = false;

  if (seconds < 0) {
    isNegative = true;
    seconds = Math.abs(seconds);
  }

  var hour = Math.floor(seconds / 3600);
  var minute = Math.round((seconds - hour * 3600) / 60);
  var formatedHour = hour < 10 ? "0" + hour : hour;

  if (minute < 10) {
    time = formatedHour + ":0" + minute;
  } else {
    time = formatedHour + ":" + minute;
  }

  if (format === 'HH:mm:ss') {
    var second = Math.floor(seconds - hour * 3600 - minute * 60);

    if (second < 10) {
      time = time + ":0" + second;
    } else {
      time = time + ":" + second;
    }
  }

  if (isNegative) {
    time = "-" + time;
  }

  return time;
};
var calculateTime = function calculateTime(date, startInput, endInput, durationInput) {
  var startTime;
  var endTime;

  if (startInput) {
    startTime = new TcDate(date).startOf('day').add(formatToSeconds(startInput).seconds, 'second');
  }

  if (endInput) {
    endTime = new TcDate(date).startOf('day').add(formatToSeconds(endInput).seconds, 'second');
  }

  var duration = formatToSeconds(durationInput).seconds;

  if (startTime && endTime) {
    var differenceInMinutes = endTime.diff(startTime.toDate(), 'minute');

    if (differenceInMinutes < 0) {
      differenceInMinutes = 24 * 60 + differenceInMinutes;
      endTime = endTime.add(1, 'day');
    }

    duration = differenceInMinutes * 60; // convert minutes to seconds
  } else if (duration !== null && endTime) {
    startTime = endTime.subtract(duration, 'second');
  } else if (duration !== null && startTime) {
    endTime = startTime.add(duration, 'second');
  }

  return {
    start: startTime ? startTime.toDate() : null,
    end: endTime ? endTime.toDate() : null,
    duration: duration
  };
};

var LocalStorageService = /*#__PURE__*/function () {
  function LocalStorageService() {
    this.localStorageSupported = typeof window['localStorage'] != 'undefined' && window['localStorage'] != null;
  }

  var _proto = LocalStorageService.prototype;

  _proto.add = function add(key, item) {
    if (!this.localStorageSupported) {
      return;
    }

    localStorage.setItem(key, item);
  };

  _proto.get = function get(key) {
    if (!this.localStorageSupported) {
      return null;
    }

    return localStorage.getItem(key);
  };

  _proto.exists = function exists(key, value) {
    if (!this.localStorageSupported) {
      return false;
    }

    return localStorage.getItem(key) === value;
  };

  _proto.remove = function remove(key) {
    if (!this.localStorageSupported) {
      return;
    }

    localStorage.removeItem(key);
  };

  return LocalStorageService;
}();

exports.LocalStorageService = LocalStorageService;
exports.TcDate = TcDate;
exports.calculateTime = calculateTime;
exports.cloneObject = cloneObject;
exports.compareArray = compareArray;
exports.delay = delay;
exports.dynamicSort = dynamicSort;
exports.dynamicSortMultiple = dynamicSortMultiple;
exports.enumToSelectList = enumToSelectList;
exports.filterBy = filterBy;
exports.formatCurrency = formatCurrency;
exports.formatDistance = formatDistance;
exports.formatFloat = formatFloat;
exports.formatNumber = formatNumber;
exports.formatTime = formatTime;
exports.formatToSeconds = formatToSeconds;
exports.formatToTime = formatToTime;
exports.formatUppercase = formatUppercase;
exports.getDateLocale = getDateLocale;
exports.getInputValueByName = getInputValueByName;
exports.getNumeric = getNumeric;
exports.getShortLocaleCode = getShortLocaleCode;
exports.globalVarExists = globalVarExists;
exports.guid = guid;
exports.hasSubArray = hasSubArray;
exports.hoursToSeconds = hoursToSeconds;
exports.imageFileToBase64 = imageFileToBase64;
exports.isMobile = isMobile;
exports.maxChar = maxChar;
exports.minimumDelay = minimumDelay;
exports.mod = mod;
exports.nameOf = nameOf;
exports.roundNumber = roundNumber;
exports.secondsToHours = secondsToHours;
exports.setInputCheckedByName = setInputCheckedByName;
exports.setInputValueByName = setInputValueByName;
exports.slugify = slugify;
exports.sortBy = sortBy;
exports.sortCaseInsensitive = sortCaseInsensitive;
exports.toggleArray = toggleArray;
exports.tryParseFloat = tryParseFloat;
exports.tryParseInt = tryParseInt;
exports.unformatCurrency = unformatCurrency;
//# sourceMappingURL=timechimp-typescript-helpers.cjs.development.js.map
